@@ -26,6 +26,10 @@ Dialog_FieldLayout::Dialog_FieldLayout(BaseObjectType* cobject, const Glib::RefP
 : Gtk::Dialog(cobject),
   m_label_field_name(0),
   m_checkbutton_editable(0),
+  m_radiobutton_title_default(0),
+  m_label_title_default(0),
+  m_radiobutton_title_custom(0),
+  m_entry_title_custom(0),
   m_box_formatting_placeholder(0),
   m_radiobutton_custom_formatting(0),
   m_box_formatting(0)
@@ -33,6 +37,11 @@ Dialog_FieldLayout::Dialog_FieldLayout(BaseObjectType* cobject, const Glib::RefP
   refGlade->get_widget("label_field_name", m_label_field_name);
   refGlade->get_widget("checkbutton_editable", m_checkbutton_editable);
 
+  refGlade->get_widget("radiobutton_use_title_default", m_radiobutton_title_default);
+  refGlade->get_widget("label_title_default", m_label_title_default);
+  refGlade->get_widget("radiobutton_use_title_custom", m_radiobutton_title_custom);
+  refGlade->get_widget("entry_title_custom", m_entry_title_custom);
+
   //Get the place to put the Formatting stuff:
   refGlade->get_widget("radiobutton_use_custom", m_radiobutton_custom_formatting);
   refGlade->get_widget("box_formatting_placeholder", m_box_formatting_placeholder);
@@ -62,34 +71,53 @@ Dialog_FieldLayout::~Dialog_FieldLayout()
   remove_view(m_box_formatting);
 }
 
-void Dialog_FieldLayout::set_field(const LayoutItem_Field& field, const Glib::ustring& table_name)
+void Dialog_FieldLayout::set_field(const sharedptr<const LayoutItem_Field>& field, const Glib::ustring& table_name)
 {
-  m_layout_item = field;
+  m_layout_item = glom_sharedptr_clone(field);
   m_table_name = table_name;
 
-  m_label_field_name->set_text( field.get_layout_display_name() );
+  m_label_field_name->set_text( field->get_layout_display_name() );
 
-  m_checkbutton_editable->set_active( field.get_editable() );
+  m_checkbutton_editable->set_active( field->get_editable() );
 
-  m_radiobutton_custom_formatting->set_active( !field.get_formatting_use_default() );
-  m_box_formatting->set_formatting(field.m_formatting, table_name, field.m_field);
+  //Calculated fields can never be edited:
+  sharedptr<const Field> field_details = field->get_full_field_details();
+  const bool editable_allowed = field_details && !field_details->get_has_calculation();
+  m_checkbutton_editable->set_sensitive(editable_allowed);
+
+  //Custom title:
+  Glib::ustring title_custom;
+  if(field->get_title_custom())
+    title_custom = field->get_title_custom()->get_title();
+
+  m_radiobutton_title_custom->set_active( !title_custom.empty() );
+  m_entry_title_custom->set_text(title_custom);
+  m_label_title_default->set_text(field->get_title_or_name());
+
+  //Formatting:
+  m_radiobutton_custom_formatting->set_active( !field->get_formatting_use_default() );
+  m_box_formatting->set_formatting(field->m_formatting, table_name, field->get_full_field_details());
 
   enforce_constraints();
 }
 
-bool Dialog_FieldLayout::get_field_chosen(LayoutItem_Field& field) const
+sharedptr<LayoutItem_Field> Dialog_FieldLayout::get_field_chosen() const
 {
-  m_layout_item.set_editable( m_checkbutton_editable->get_active() );
+  m_layout_item->set_editable( m_checkbutton_editable->get_active() );
 
-  m_layout_item.set_formatting_use_default( !m_radiobutton_custom_formatting->get_active() );
-  m_box_formatting->get_formatting(m_layout_item.m_formatting);
+  m_layout_item->set_formatting_use_default( !m_radiobutton_custom_formatting->get_active() );
+  m_box_formatting->get_formatting(m_layout_item->m_formatting);
 
-  g_warning("Dialog_FieldLayout::get_field_chosen(): multiline=%d", m_layout_item.m_formatting.get_text_format_multiline());
+  sharedptr<CustomTitle> title_custom = sharedptr<CustomTitle>::create();
+  if(m_radiobutton_title_custom->get_active())
+  {
+    std::cout << "setting title custom: " << m_entry_title_custom->get_text() << std::endl;
+    title_custom->set_title(m_entry_title_custom->get_text());
+  }
 
-  field = m_layout_item;
- g_warning("Dialog_FieldLayout::get_field_chosen() 2 : multiline=%d", field.m_formatting.get_text_format_multiline());
+  m_layout_item->set_title_custom(title_custom);
 
-  return true;
+  return glom_sharedptr_clone(m_layout_item);
 }
 
 void Dialog_FieldLayout::on_radiobutton_custom_formatting()
