@@ -71,7 +71,7 @@ void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustri
     m_combo_relationship->set_selected_relationship( field->get_relationship() );
   }
   else
-    m_combo_relationship->set_selected_parent_table(table_name); //TODO: Show the title too.
+    m_combo_relationship->set_selected_parent_table(table_name, document->get_table_title(table_name)); 
 
   //Select the current field at the start:
   if(field)
@@ -92,6 +92,9 @@ void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustri
     if(iterFound != m_model->children().end())
     {
       m_treeview->get_selection()->select(iterFound);
+
+      //Make sure that it is scrolled into view:
+      m_treeview->scroll_to_row(Gtk::TreeModel::Path(iterFound));
     }
   }
 }
@@ -121,10 +124,11 @@ void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustri
     m_combo_relationship->set_display_parent_table(table_name, document->get_table_title(table_name));
 
     //Add the relationships for this table:
-    m_combo_relationship->set_relationships(vecRelationships, table_name, document->get_table_title(table_name));
+    const Glib::ustring table_title = document->get_table_title(table_name);
+    m_combo_relationship->set_relationships(vecRelationships, table_name, table_title);
 
     //Set the table name and title:
-    m_combo_relationship->set_selected_parent_table(table_name);
+    m_combo_relationship->set_selected_parent_table(table_name, table_title);
 
     //Fill the treeview:
     m_model->clear();
